@@ -2,8 +2,8 @@
 
 /*
  * $Author: tom $
- * $Date: 2021/08/25 23:34:40 $
- * $Revision: 1.225 $
+ * $Date: 2024/03/31 16:54:49 $
+ * $Revision: 1.229 $
  */
 
 #define L_MARKER '<'
@@ -55,11 +55,11 @@ void cleanChtype (chtype *s, int len, chtype character)
  */
 void alignxy (WINDOW *window, int *xpos, int *ypos, int boxWidth, int boxHeight)
 {
-   int first, gap, last;
+   int first, gap, limit, last;
 
    first = getbegx (window);
-   last = getmaxx (window);
-   if ((gap = (last - boxWidth)) < 0)
+   limit = getmaxx (window);
+   if ((gap = (limit - boxWidth)) < 0)
       gap = 0;
    last = first + gap;
 
@@ -81,10 +81,11 @@ void alignxy (WINDOW *window, int *xpos, int *ypos, int boxWidth, int boxHeight)
 	 (*xpos) = first;
       break;
    }
+   (void)last;
 
    first = getbegy (window);
-   last = getmaxy (window);
-   if ((gap = (last - boxHeight)) < 0)
+   limit = getmaxy (window);
+   if ((gap = (limit - boxHeight)) < 0)
       gap = 0;
    last = first + gap;
 
@@ -225,7 +226,7 @@ chtype *copyChtype (const chtype *original)
  */
 char **copyCharList (const char **list)
 {
-   size_t size = (size_t) lenCharList (list) + 1;
+   size_t size = (size_t)lenCharList (list) + 1;
    char **result = typeMallocN (char *, size);
 
    if (result != 0)
@@ -239,7 +240,7 @@ char **copyCharList (const char **list)
 
 chtype **copyChtypeList (const chtype **list)
 {
-   size_t size = (size_t) lenChtypeList (list) + 1;
+   size_t size = (size_t)lenChtypeList (list) + 1;
    chtype **result = typeMallocN (chtype *, size);
 
    if (result != 0)
@@ -276,6 +277,46 @@ int lenChtypeList (const chtype **list)
    return result;
 }
 
+int CDKchdir (const char *directory)
+{
+   int result;
+
+#ifdef HAVE_WORDEXP
+   wordexp_t expanded;
+   if (wordexp (directory, &expanded, WRDE_NOCMD) == 0)
+   {
+      if (expanded.we_wordc == 1 && strcmp (expanded.we_wordv[0], directory))
+	 result = chdir (expanded.we_wordv[0]);
+      else
+	 result = chdir (directory);
+      wordfree (&expanded);
+   }
+   else
+#endif
+      result = chdir (directory);
+   return result;
+}
+
+FILE *CDKopenFile (const char *filename, const char *mode)
+{
+   FILE *result;
+
+#ifdef HAVE_WORDEXP
+   wordexp_t expanded;
+   if (wordexp (filename, &expanded, WRDE_NOCMD) == 0)
+   {
+      if (expanded.we_wordc == 1 && strcmp (expanded.we_wordv[0], filename))
+	 result = fopen (expanded.we_wordv[0], mode);
+      else
+	 result = fopen (filename, mode);
+      wordfree (&expanded);
+   }
+   else
+#endif
+      result = fopen (filename, mode);
+   return result;
+}
+
 /*
  * This reads a file and sticks it into the char *** provided.
  */
@@ -287,7 +328,7 @@ int CDKreadFile (const char *filename, char ***array)
    unsigned used = 0;
 
    /* Can we open the file?  */
-   if ((fd = fopen (filename, "r")) == 0)
+   if ((fd = CDKopenFile (filename, "r")) == 0)
    {
       return (-1);
    }
@@ -308,8 +349,6 @@ int CDKreadFile (const char *filename, char ***array)
 
 static int encodeAttribute (const char *string, int from, chtype *mask)
 {
-   int pair = 0;
-
    *mask = 0;
    switch (string[from + 1])
    {
@@ -340,8 +379,8 @@ static int encodeAttribute (const char *string, int from, chtype *mask)
    else
    {
       int digits;
+      int pair = 0;
 
-      pair = 0;
       for (digits = 1; digits <= 3; ++digits)
       {
 	 if (!isdigit (CharOf (string[1 + from])))
@@ -462,8 +501,6 @@ static unsigned decodeAttribute (char *string,
 chtype *char2Chtype (const char *string, int *to, int *align)
 {
    chtype *result = 0;
-   chtype attrib;
-   chtype lastChar;
    chtype mask;
 
    (*to) = 0;
@@ -480,6 +517,7 @@ chtype *char2Chtype (const char *string, int *to, int *align)
        */
       for (pass = 0; pass < 2; pass++)
       {
+	 chtype attrib;
 	 int insideMarker;
 	 int from;
 	 int adjust;
@@ -614,7 +652,7 @@ chtype *char2Chtype (const char *string, int *to, int *align)
 		  break;
 	       case '#':
 		  {
-		     lastChar = 0;
+		     chtype lastChar = 0;
 		     switch (string[from + 2])
 		     {
 		     case 'L':
@@ -1465,7 +1503,7 @@ void deleteCursesWindow (WINDOW *window)
 
 /*
  * This moves a given window (if we're able to set the window's beginning).
- * We do not use mvwin(), because it does (usually) not move subwindows.
+ * We prefer to not use mvwin(), because SVr4 curses does not move subwindows.
  */
 void moveCursesWindow (WINDOW *window, int xdiff, int ydiff)
 {
@@ -1474,11 +1512,17 @@ void moveCursesWindow (WINDOW *window, int xdiff, int ydiff)
       int xpos, ypos;
 
       getbegyx (window, ypos, xpos);
+#if defined(setbegyx)
       (void)setbegyx (window, (short)ypos, (short)xpos);
       xpos += xdiff;
       ypos += ydiff;
       werase (window);
       (void)setbegyx (window, (short)ypos, (short)xpos);
+#elif defined(HAVE_MVWIN)
+      (void)mvwin (window, (short)(ypos + ydiff), (short)(xpos + xdiff));
+#endif
+      (void)ypos;
+      (void)xpos;
    }
 }
 
