@@ -3,13 +3,14 @@
 
 /*
  * $Author: tom $
- * $Date: 2013/06/16 15:00:10 $
- * $Revision: 1.80 $
+ * $Date: 2024/03/31 15:36:33 $
+ * $Revision: 1.87 $
  */
 
 /*
  * Declare file local prototypes.
  */
+/* *INDENT-OFF* */
 static BINDFN_PROTO (completeFilenameCB);
 static BINDFN_PROTO (displayFileInfoCB);
 static BINDFN_PROTO (fselectAdjustScrollCB);
@@ -24,6 +25,7 @@ static char *format1StrVal (const char *format, const char *string, int value);
 static char *trim1Char (char *source);
 static int createList (CDKFSELECT *widget, CDK_CSTRING2 list, int listSize);
 static void setPWD (CDKFSELECT *fselect);
+/* *INDENT-ON* */
 
 DeclareSetXXchar (static, _setMy);
 DeclareCDKObjects (FSELECT, Fselect, _setMy, String);
@@ -207,7 +209,7 @@ CDKFSELECT *newCDKFselect (CDKSCREEN *cdkscreen,
 					boxHeight - tempHeight,
 					tempWidth,
 					0,
-					(CDK_CSTRING2) fselect->dirContents,
+					(CDK_CSTRING2)fselect->dirContents,
 					fselect->fileCounter,
 					NONUMBERS, fselect->highlight,
 					Box, FALSE);
@@ -354,7 +356,6 @@ static void _drawCDKFselect (CDKOBJS *object, boolean Box GCC_UNUSED)
  */
 char *activateCDKFselect (CDKFSELECT *fselect, chtype *actions)
 {
-   chtype input = 0;
    boolean functionKey;
    char *ret = 0;
 
@@ -365,7 +366,7 @@ char *activateCDKFselect (CDKFSELECT *fselect, chtype *actions)
    {
       for (;;)
       {
-	 input = (chtype)getchCDKObject (ObjOf (fselect->entryField), &functionKey);
+	 chtype input = (chtype)getchCDKObject (ObjOf (fselect->entryField), &functionKey);
 
 	 /* Inject the character into the widget. */
 	 ret = injectCDKFselect (fselect, input);
@@ -420,8 +421,8 @@ static int _injectCDKFselect (CDKOBJS *object, chtype input)
    }
 
    /* Can we change into the directory? */
-   file = chdir (filename);
-   if (chdir (fselect->pwd) != 0)
+   file = CDKchdir (filename);
+   if (CDKchdir (fselect->pwd) != 0)
    {
       return 0;
    }
@@ -475,8 +476,6 @@ void setCDKFselect (CDKFSELECT *fselect,
    CDKSCROLL *fscroll   = fselect->scrollField;
    CDKENTRY *fentry     = fselect->entryField;
    char *tempDir        = 0;
-   char *mesg[10];
-   char *newDirectory;
 
    /* Keep the info sent to us. */
    fselect->fieldAttribute = fieldAttrib;
@@ -490,6 +489,8 @@ void setCDKFselect (CDKFSELECT *fselect,
    /* Only do the directory stuff if the directory is not null. */
    if (directory != 0)
    {
+      char *newDirectory;
+
       /* Try to expand the directory if it starts with a ~ */
       if ((tempDir = expandTilde (directory)) != 0)
       {
@@ -501,8 +502,10 @@ void setCDKFselect (CDKFSELECT *fselect,
       }
 
       /* Change directories. */
-      if (chdir (newDirectory) != 0)
+      if (CDKchdir (newDirectory) != 0)
       {
+	 char *mesg[10];
+
 	 Beep ();
 
 	 /* Could not get into the directory, pop up a little message. */
@@ -512,7 +515,7 @@ void setCDKFselect (CDKFSELECT *fselect,
 	 mesg[3] = copyChar ("<C>Press Any Key To Continue.");
 
 	 /* Pop Up a message. */
-	 popupLabel (ScreenOf (fselect), (CDK_CSTRING2) mesg, 4);
+	 popupLabel (ScreenOf (fselect), (CDK_CSTRING2)mesg, 4);
 
 	 /* Clean up some memory. */
 	 freeCharList (mesg, 4);
@@ -572,7 +575,7 @@ void setCDKFselect (CDKFSELECT *fselect,
 
    /* Set the values in the scrolling list. */
    setCDKScrollItems (fscroll,
-		      (CDK_CSTRING2) fselect->dirContents,
+		      (CDK_CSTRING2)fselect->dirContents,
 		      fselect->fileCounter,
 		      FALSE);
 }
@@ -584,7 +587,6 @@ int setCDKFselectDirContents (CDKFSELECT *fselect)
 {
    struct stat fileStat;
    char **dirList = 0;
-   char *oldItem;
    int fileCount;
    int x = 0;
 
@@ -605,6 +607,7 @@ int setCDKFselectDirContents (CDKFSELECT *fselect)
    /* Set the properties of the files. */
    for (x = 0; x < fselect->fileCounter; x++)
    {
+      char *oldItem;
       const char *attr = "";
       const char *mode = "?";
 
@@ -675,7 +678,7 @@ int setCDKFselectDirectory (CDKFSELECT *fselect, const char *directory)
    if (fselect->pwd != directory)
    {
       /* Try to chdir into the given directory. */
-      if (chdir (directory) != 0)
+      if (CDKchdir (directory) != 0)
       {
 	 result = 0;
       }
@@ -696,7 +699,7 @@ int setCDKFselectDirectory (CDKFSELECT *fselect, const char *directory)
 	 {
 	    /* Set the values in the scrolling list. */
 	    setCDKScrollItems (fscroll,
-			       (CDK_CSTRING2) fselect->dirContents,
+			       (CDK_CSTRING2)fselect->dirContents,
 			       fselect->fileCounter,
 			       FALSE);
 	 }
@@ -847,7 +850,7 @@ void setCDKFselectContents (CDKFSELECT *widget,
 
    /* Set the information in the scrolling list. */
    setCDKScroll (scrollp,
-		 (CDK_CSTRING2) widget->dirContents,
+		 (CDK_CSTRING2)widget->dirContents,
 		 widget->fileCounter,
 		 NONUMBERS,
 		 scrollp->highlight,
@@ -1021,39 +1024,41 @@ static int displayFileInfoCB (EObjectType objectType GCC_UNUSED,
    int intMode;
    boolean functionKey;
 
-   /* Get the file name. */
    filename = fselect->entryField->info;
 
-   /* Get specific information about the files. */
-   lstat (filename, &fileStat);
-
-   /* Determine the file type. */
-   switch (mode2Filetype (fileStat.st_mode))
+   if (lstat (filename, &fileStat) == 0)
+   {
+      switch (mode2Filetype (fileStat.st_mode))
+      {
+      case 'l':
+	 filetype = "Symbolic Link";
+	 break;
+      case '@':
+	 filetype = "Socket";
+	 break;
+      case '-':
+	 filetype = "Regular File";
+	 break;
+      case 'd':
+	 filetype = "Directory";
+	 break;
+      case 'c':
+	 filetype = "Character Device";
+	 break;
+      case 'b':
+	 filetype = "Block Device";
+	 break;
+      case '&':
+	 filetype = "FIFO Device";
+	 break;
+      default:
+	 filetype = "Unknown";
+	 break;
+      }
+   }
+   else
    {
-   case 'l':
-      filetype = "Symbolic Link";
-      break;
-   case '@':
-      filetype = "Socket";
-      break;
-   case '-':
-      filetype = "Regular File";
-      break;
-   case 'd':
-      filetype = "Directory";
-      break;
-   case 'c':
-      filetype = "Character Device";
-      break;
-   case 'b':
-      filetype = "Block Device";
-      break;
-   case '&':
-      filetype = "FIFO Device";
-      break;
-   default:
       filetype = "Unknown";
-      break;
    }
 
    /* Get the user name and group name. */
@@ -1088,7 +1093,7 @@ static int displayFileInfoCB (EObjectType objectType GCC_UNUSED,
    /* Create the pop up label. */
    infoLabel = newCDKLabel (entry->obj.screen,
 			    CENTER, CENTER,
-			    (CDK_CSTRING2) mesg, 9,
+			    (CDK_CSTRING2)mesg, 9,
 			    TRUE, FALSE);
    drawCDKLabel (infoLabel, TRUE);
    getchCDKObject (ObjOf (infoLabel), &functionKey);
@@ -1159,14 +1164,8 @@ static int completeFilenameCB (EObjectType objectType GCC_UNUSED,
    char *mydirname      = dirName (filename);
    char *newFilename    = 0;
    size_t filenameLen   = 0;
-   int currentIndex     = 0;
-   int matches          = 0;
-   int baseChars        = 0;
-   int secondaryMatches = 0;
    int isDirectory;
    char **list;
-   int Index, x;
-   int difference, absoluteDifference;
 
    /* Make sure the filename is not null/empty. */
    if (filename == 0 ||
@@ -1174,6 +1173,7 @@ static int completeFilenameCB (EObjectType objectType GCC_UNUSED,
    {
       Beep ();
       freeChar (filename);
+      freeChar (mydirname);
       return (TRUE);
    }
 
@@ -1187,9 +1187,13 @@ static int completeFilenameCB (EObjectType objectType GCC_UNUSED,
    }
 
    /* Make sure we can change into the directory. */
-   isDirectory = chdir (filename);
-   if (chdir (fselect->pwd) != 0)
+   isDirectory = CDKchdir (filename);
+   if (CDKchdir (fselect->pwd) != 0)
+   {
+      freeChar (filename);
+      freeChar (mydirname);
       return FALSE;
+   }
 
    setCDKFselect (fselect,
 		  isDirectory ? mydirname : filename,
@@ -1217,13 +1221,15 @@ static int completeFilenameCB (EObjectType objectType GCC_UNUSED,
    /* Create the file list. */
    if ((list = typeMallocN (char *, fselect->fileCounter)) != 0)
    {
+      int Index, x;
+
       for (x = 0; x < fselect->fileCounter; x++)
       {
 	 list[x] = contentToPath (fselect, fselect->dirContents[x]);
       }
 
       /* Look for a unique filename match. */
-      Index = searchList ((CDK_CSTRING2) list, fselect->fileCounter, filename);
+      Index = searchList ((CDK_CSTRING2)list, fselect->fileCounter, filename);
 
       /* If the index is less than zero, return we didn't find a match. */
       if (Index < 0)
@@ -1233,8 +1239,8 @@ static int completeFilenameCB (EObjectType objectType GCC_UNUSED,
       else
       {
 	 /* Move to the current item in the scrolling list. */
-	 difference = Index - scrollp->currentItem;
-	 absoluteDifference = abs (difference);
+	 int difference = Index - scrollp->currentItem;
+	 int absoluteDifference = abs (difference);
 	 if (difference < 0)
 	 {
 	    for (x = 0; x < absoluteDifference; x++)
@@ -1256,9 +1262,9 @@ static int completeFilenameCB (EObjectType objectType GCC_UNUSED,
 	     0 != list[Index + 1] &&
 	     0 == strncmp (list[Index + 1], filename, filenameLen))
 	 {
-	    currentIndex = Index;
-	    baseChars = (int)filenameLen;
-	    matches = 0;
+	    int currentIndex = Index;
+	    int baseChars = (int)filenameLen;
+	    int matches = 0;
 
 	    /* Determine the number of files which match. */
 	    while (currentIndex < fselect->fileCounter)
@@ -1276,7 +1282,7 @@ static int completeFilenameCB (EObjectType objectType GCC_UNUSED,
 	    /* Start looking for the common base characters. */
 	    for (;;)
 	    {
-	       secondaryMatches = 0;
+	       int secondaryMatches = 0;
 	       for (x = Index; x < Index + matches; x++)
 	       {
 		  if (list[Index][baseChars] == list[x][baseChars])
@@ -1336,8 +1342,8 @@ void deleteFileCB (EObjectType objectType GCC_UNUSED, void *object, void *client
 
    /* Create the dialog box. */
    question = newCDKDialog (ScreenOf (fselect), CENTER, CENTER,
-			    (CDK_CSTRING2) mesg, 2,
-			    (CDK_CSTRING2) buttons, 2,
+			    (CDK_CSTRING2)mesg, 2,
+			    (CDK_CSTRING2)buttons, 2,
 			    A_REVERSE, TRUE, TRUE, FALSE);
    freeCharList (mesg, 2);
 
@@ -1364,7 +1370,7 @@ void deleteFileCB (EObjectType objectType GCC_UNUSED, void *object, void *client
 	 mesg[0] = copyChar (errorMessage ("<C>Cannot delete file: %s"));
 	 mesg[1] = copyChar (" ");
 	 mesg[2] = copyChar ("<C>Press any key to continue.");
-	 popupLabel (ScreenOf (fselect), (CDK_CSTRING2) mesg, 3);
+	 popupLabel (ScreenOf (fselect), (CDK_CSTRING2)mesg, 3);
 	 freeCharList (mesg, 3);
       }
    }
@@ -1406,11 +1412,12 @@ static int fselectAdjustScrollCB (EObjectType objectType GCC_UNUSED,
    CDKFSELECT *fselect  = (CDKFSELECT *)clientData;
    CDKSCROLL *scrollp   = (CDKSCROLL *)fselect->scrollField;
    CDKENTRY *entry      = (CDKENTRY *)fselect->entryField;
-   char *current;
-   char *temp;
 
    if (scrollp->listSize > 0)
    {
+      char *current;
+      char *temp;
+
       /* Move the scrolling list. */
       injectMyScroller (fselect, key);
 
@@ -1449,7 +1456,7 @@ static char *format1Date (const char *format, time_t value)
    char *result;
    char *temp = ctime (&value);
 
-   if ((result = (char *)malloc (strlen (format) + strlen (temp))) != 0)
+   if ((result = (char *)malloc (strlen (format) + strlen (temp) + 1)) != 0)
    {
       sprintf (result, format, trim1Char (temp));
    }
@@ -1465,7 +1472,10 @@ static char *format1Number (const char *format, long value)
    return result;
 }
 
-static char *format3String (const char *format, const char *s1, const char *s2, const char *s3)
+static char *format3String (const char *format,
+			    const char *s1,
+			    const char *s2,
+			    const char *s3)
 {
    char *result;
 
