@@ -2,8 +2,8 @@
 
 /*
  * $Author: tom $
- * $Date: 2013/06/16 13:19:15 $
- * $Revision: 1.25 $
+ * $Date: 2021/12/16 00:42:01 $
+ * $Revision: 1.29 $
  */
 
 /*
@@ -18,25 +18,25 @@ DeclareCDKObjects (<UPPER>, <MIXED>, setCdk, <DTYPE>);
  * This function creates a widget.
  */
 CDK<UPPER> *newCDK<MIXED> (CDKSCREEN *cdkscreen,
-				 int xplace,
-				 int yplace,
-				 const char *title,
-				 const char *label,
-				 chtype filler,
-				 int fieldWidth,
-				 <CTYPE> start,
-				 <CTYPE> low,
-				 <CTYPE> high,
-				 <CTYPE> inc,
-				 <CTYPE> fastInc,
+			   int xplace,
+			   int yplace,
+			   const char *title,
+			   const char *label,
+			   chtype filler,
+			   int fieldWidth,
+			   <CTYPE> start,
+			   <CTYPE> low,
+			   <CTYPE> high,
+			   <CTYPE> inc,
+			   <CTYPE> fastInc,
 #if <FLOAT>
-				 int digits,
+			   int digits,
 #endif <FLOAT>
-				 boolean Box,
-				 boolean shadow)
+			   boolean Box,
+			   boolean shadow)
 {
    /* *INDENT-EQLS* */
-   CDK<UPPER> *widget = 0;
+   CDK<UPPER> *widget   = 0;
    int parentWidth      = getmaxx (cdkscreen->window);
    int parentHeight     = getmaxy (cdkscreen->window);
    int boxHeight;
@@ -73,7 +73,8 @@ CDK<UPPER> *newCDK<MIXED> (CDKSCREEN *cdkscreen,
 #if <FLOAT>
    widget->digits       = digits;
 #endif <FLOAT>
-   highValueLen         = formattedSize (widget, high);
+   highValueLen         = MAXIMUM (formattedSize (widget, low),
+			           formattedSize (widget, high));
 
    /*
     * If the fieldWidth is a negative value, the fieldWidth will
@@ -190,7 +191,7 @@ CDK<UPPER> *newCDK<MIXED> (CDKSCREEN *cdkscreen,
    for (x = 0; x < (int)SIZEOF (bindings); ++x)
       bindCDKObject (v<UPPER>,
 		     widget,
-		     (chtype) bindings[x].from,
+		     (chtype)bindings[x].from,
 		     getcCDKBind,
 		     (void *)(long)bindings[x].to);
 
@@ -211,15 +212,14 @@ CDK<UPPER> *newCDK<MIXED> (CDKSCREEN *cdkscreen,
 
    if (actions == 0)
    {
-      chtype input = 0;
       boolean functionKey;
 
       for (;;)
       {
-	 input = (chtype) getchCDKObject (ObjOf (widget), &functionKey);
+	 chtype input = (chtype)getchCDKObject (ObjOf (widget), &functionKey);
 
 	 /* Inject the character into the widget. */
-	 ret = (<CTYPE>) injectCDK<MIXED> (widget, input);
+	 ret = (<CTYPE>)injectCDK<MIXED> (widget, input);
 	 if (widget->exitType != vEARLY_EXIT)
 	 {
 	    return ret;
@@ -234,7 +234,7 @@ CDK<UPPER> *newCDK<MIXED> (CDKSCREEN *cdkscreen,
       /* Inject each character one at a time. */
       for (x = 0; x < length; x++)
       {
-	 ret = (<CTYPE>) injectCDK<MIXED> (widget, actions[x]);
+	 ret = (<CTYPE>)injectCDK<MIXED> (widget, actions[x]);
 	 if (widget->exitType != vEARLY_EXIT)
 	 {
 	    return ret;
@@ -352,7 +352,6 @@ static bool removeChar (char *string, int col)
 static bool performEdit (CDK<UPPER> *widget, chtype input)
 {
    bool result = FALSE;
-   bool modify = TRUE;
    int base = widget->fieldWidth;
    int need = formattedSize (widget, widget->current);
    char *temp = (char *)malloc ((size_t) need + 5);
@@ -370,6 +369,7 @@ static bool performEdit (CDK<UPPER> *widget, chtype input)
 
    if (temp != 0)
    {
+      bool modify = TRUE;
       int adj = (col < 0) ? (-col) : 0;
       if (adj)
       {
@@ -381,7 +381,7 @@ static bool performEdit (CDK<UPPER> *widget, chtype input)
       strcpy (temp + need, " ");
       if (isChar (input))	/* replace the char at the cursor */
       {
-	 temp[col] = (char) (input);
+	 temp[col] = (char)(input);
       }
       else if (input == KEY_BACKSPACE)	/* delete the char before the cursor */
       {
@@ -401,7 +401,7 @@ static bool performEdit (CDK<UPPER> *widget, chtype input)
 	  && value >= widget->low
 	  && value <= widget->high)
       {
-	 setCDK<MIXED>Value (widget, (<CTYPE>) value);
+	 setCDK<MIXED>Value (widget, (<CTYPE>)value);
 	 result = TRUE;
       }
       free (data);
@@ -652,8 +652,8 @@ static void drawCDK<MIXED>Field (CDK<UPPER> *widget)
 {
    int fillerCharacters, x;
    char temp[256];
-   double step = ((double)widget->fieldWidth
-		 / (double)(widget->high - widget->low));
+   double step = ((double)widget->fieldWidth /
+		  (double)(widget->high - widget->low));
 
    /* Determine how many filler characters need to be drawn. */
    fillerCharacters = (int)((widget->current - widget->low) * step);
@@ -821,7 +821,7 @@ void setCDK<MIXED>LowHigh (CDK<UPPER> *widget, <CTYPE> low, <CTYPE> high)
       widget->low = low;
       widget->high = high;
    }
-   else if (low > high)
+   else
    {
       widget->low = high;
       widget->high = low;
